/*
 * Copyright (c) 2024 ShinGeTsu Meter.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */
#pragma once

// GPOIO
#define LED_PIN      25
#define TA_RE1       9
#define TA_RE2       10
#define BUTTON_RST   11
#define BUTTON_COUNT 12
#define BUTTON_AUTO  13

// ロータリーエンコーダ移動方向判定用
#define ROTARY_DIRECTION \
    { 0, 1, -1, 0, -1, 0, 0, 1, 1, 0, 0, -1, 0, -1, 1, 0 }

// TA計算用定数
#define TA_MAX 6.5       // TA最大値
#define TA_MIN 0.9412    // TA最小値

// 時間
#define SAMPLE_WAIT_uS (50 * 1000)     // サンプリング間隔
#define UPDATE_WAIT_uS (500 * 1000)    // LCD更新間隔
#define RESET_WAIT_uS  (500 * 1000)    // 自動リセットの待ち時間
#define EVENT_BLOCK_uS (10 * 1000)     // 同じイベントの連続実行を抑止する時間

// TA履歴
#define HIST_uS      (1500 * 1000)                 // 履歴保存期間
#define TA_HIST_SIZE (HIST_uS / SAMPLE_WAIT_uS)    // TA履歴サイズ
#define TA_BLOCK_TH  0.800                         // 履歴中のTA範囲がこれより大きい場合、自動リセット/TAカウントを抑制

// メーターの目盛り ※時計周りに目盛り値が減少、左端：15 → セット位置：0 → 右端：-25
#define REFV_DIV      1        // 定電圧とrefピンの電圧比
#define SCALE_POS_SET 13.0     // セット位置のオフセット値
#define SCALE_POS_MAX 13.5     // 自動リセット左端目盛り
#define SCALE_POS_MIN -23.5    // 自動リセット右端目盛り

// 表示モード
typedef enum {
    VIEW_1 = 0,
    VIEW_2,
    VIEW_3,
} view_t;
